@@ -50,8 +50,8 @@ def debhelper_common_args(f, minimal=False):
     @click.option("--create-in-sourcedir")
     # Ignore the following parameters
     @click.option("-O--no-parallel", is_flag=True, hidden=True)
-    @click.option("-O--buildsystem", is_flag=True, hidden=True)
-    @click.option("-O--builddirectory", is_flag=True, hidden=True)
+    @click.option("-O--buildsystem",  hidden=True)
+    @click.option("-O--builddirectory",  hidden=True)
     def wrapper(*args, **kwargs):
 
         global verbose
